@@ -3,12 +3,18 @@ use strict;
 use Acme::MetaSyntactic (); # do not export metaname and friends
 use Acme::MetaSyntactic::RemoteList;
 use List::Util qw( shuffle );
+use Carp;
 
 our @ISA = qw( Acme::MetaSyntactic::RemoteList );
 
 sub init {
+    my ($self, $data) = @_;
     my $class = caller(0);
-    my $data  = Acme::MetaSyntactic->load_data($class);
+
+    $data ||= Acme::MetaSyntactic->load_data($class);
+    croak "The optional argument to init must be a hash reference"
+      if ref $data ne 'HASH';
+
     no strict 'refs';
     no warnings;
     ${"$class\::Theme"} = ( split /::/, $class )[-1];
