@@ -4,31 +4,17 @@ use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
 
 {
-    # a very basic list
-    my $data = join "\n",
-        map { ( "\t\tLATIN CAPITAL LETTER $_", "\t\tLATIN SMALL LETTER $_" ) }
-        'A' .. 'Z';
-
-    # try to find better
-    if ( $] >= 5.006 && $] < 5.007003  ) {
-        eval { $data = require 'unicode/Name.pl'; };
+    my $data = '';
+    if ( $] =~ /^5\.006/ ) {
+        $data = require 'unicode/Name.pl';
     }
-    elsif ( $] >= 5.007003 ) {
-        eval { $data = require 'unicore/Name.pl'; };
-
-        # since v5.11.3, unicore/Name.pl creates subroutines
-        # they end up in our namespace, so get rid of them
-        undef *code_point_to_name_special;
-        undef *name_to_code_point_special;
+    elsif ( $] =~ /^5\.008/ ) {
+        $data = require 'unicore/Name.pl';
     }
-
-    # clean up the list
-    my %seen;
     $data = join ' ',
-        grep !$seen{$_}++,            # we might have aliases/duplicates
         map  { s/ \(.*\)//; y/- /_/; $_ }
         grep { $_ ne '<control>' }    # what's this for a character name?
-        map  { my @F = split /\t+/; @F > 2 ? () : $F[1] }   # remove blocks
+        map  { my @F = split /\t/; $F[1] ? () : $F[2] }   # remove blocks
         split /\n/, $data;
 
     __PACKAGE__->init( { names => $data } );
@@ -36,8 +22,6 @@ our @ISA = qw( Acme::MetaSyntactic::List );
 
 1;
 
-__END__
-
 =head1 NAME
 
 Acme::MetaSyntactic::unicode - The unicode theme
@@ -58,9 +42,6 @@ F<unicore/Name.pl>.
 
 Introduced in version 0.50, published on November 28, 2005.
 
-Updated to support more Perl versions in version 0.51, published
-on December 5, 2005.
-
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
